unit mainunit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Buttons, ExtCtrls, StdCtrls, ComCtrls, FlicPlayer, ShellAPI;

type
  TMainForm = class(TForm)
    Panel1: TPanel;
    OpenButton: TSpeedButton;
    PlayButton: TSpeedButton;
    StopButton: TSpeedButton;
    QuitButton: TSpeedButton;
    PowerFlic1: TPowerFlic;
    ListBox1: TListBox;
    PowerFlic2: TPowerFlic;
    SpeedBar: TTrackBar;
    Label1: TLabel;
    BrightnessBar: TTrackBar;
    Label2: TLabel;
    Label3: TLabel;
    ContrastBar: TTrackBar;
    ResetButton: TSpeedButton;
    CurFrame1: TLabel;
    FrameShown1: TLabel;
    CurFrame2: TLabel;
    FrameShown2: TLabel;
    FlicShown1: TLabel;
    FlicShown2: TLabel;
    Status1: TLabel;
    Status2: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    Label9: TLabel;
    Label10: TLabel;
    Label11: TLabel;
    SpeedLabel: TLabel;
    BrightnessLabel: TLabel;
    ContrastLabel: TLabel;
    Label12: TLabel;
    Label13: TLabel;
    procedure OpenButtonClick(Sender: TObject);
    procedure PlayButtonClick(Sender: TObject);
    procedure StopButtonClick(Sender: TObject);
    procedure QuitButtonClick(Sender: TObject);
    procedure SpeedBarChange(Sender: TObject);
    procedure BrightnessBarChange(Sender: TObject);
    procedure ContrastBarChange(Sender: TObject);
    procedure ResetButtonClick(Sender: TObject);
    procedure PowerFlic1FrameChange(Sender: TObject);
    procedure PowerFlic2FrameChange(Sender: TObject);
    procedure PowerFlic1Loop(Sender: TObject);
    procedure PowerFlic2Loop(Sender: TObject);
    procedure PowerFlic1Stop(Sender: TObject);
    procedure PowerFlic2Stop(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure Label12Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;


  TFlicQuery  =
  Record
    Width         : Integer;
    Height        : Integer;
    Speed         : Integer;
    Frames        : Integer;
    CurrentFrame  : Integer;
    FramesPlayed  : Integer;
    Format        : (frOLD,frNEW);
    Status        : (stPlay,stStop,stNone);
  End;

var
  MainForm      : TMainForm;
  FlicInfo   : TFlicQuery;
  LoopCount1 : Integer = 0;
  LoopCount2 : Integer = 0;

implementation

{$R *.DFM}

procedure TMainForm.OpenButtonClick(Sender: TObject);
var
  S : String;
begin
  ListBox1.Clear;
  PowerFlic1.Open;
  PowerFlic2.Open;
  If PowerFlic1.FlicOpen = True then
  Begin
    Status1.Caption := 'Open';
    PowerFlic1.QueryFlicInfo(Addr(FlicInfo));
    ListBox1.Items.Add('File Name    : '+PowerFlic1.FlicName);
    ListBox1.Items.Add('Width        : '+IntToStr(FlicInfo.Width));
    ListBox1.Items.Add('Height       : '+IntToStr(FlicInfo.Height));
    ListBox1.Items.Add('Total Frames : '+IntToStr(FlicInfo.Frames));
    Case FlicInfo.Format of
      frOLD : S := 'Old FLI format';
      frNEW : S := 'New FLC format';
    End;
    ListBox1.Items.Add('Flic Format  : '+S);
    ListBox1.Items.Add('*******************************');
  End;
  If PowerFlic2.FlicOpen = True then
  Begin
    Status2.Caption := 'Open';
    PowerFlic2.QueryFlicInfo(Addr(FlicInfo));
    ListBox1.Items.Add('File Name    : '+PowerFlic2.FlicName);
    ListBox1.Items.Add('Width        : '+IntToStr(FlicInfo.Width));
    ListBox1.Items.Add('Height       : '+IntToStr(FlicInfo.Height));
    ListBox1.Items.Add('Total Frames : '+IntToStr(FlicInfo.Frames));
    Case FlicInfo.Format of
      frOLD : S := 'Old FLI format';
      frNEW : S := 'New FLC format';
    End;
    ListBox1.Items.Add('Flic Format  : '+S);
  End;
end;

procedure TMainForm.PlayButtonClick(Sender: TObject);
begin
  If PowerFlic1.FlicOpen = True then
  Begin
    Status1.Caption := 'Playing';
    PowerFlic1.Play;
  End;
  If PowerFlic2.FlicOpen = True then
  Begin
    Status2.Caption := 'Playing';
    PowerFlic2.Play;
  End;
end;

procedure TMainForm.StopButtonClick(Sender: TObject);
begin
  PowerFlic1.Stop;
  PowerFlic2.Stop;
end;

procedure TMainForm.QuitButtonClick(Sender: TObject);
begin
  Close;
end;

procedure TMainForm.SpeedBarChange(Sender: TObject);
var
  R : Real;
  S : String;
begin
  If SpeedBar.Position > 0 then
  Begin
    R := 1000/SpeedBar.Position;
    Str(R:0:2,S);
  End
    else
  Begin
    S := 'Max';
  End;
  PowerFlic1.CustomSpeed := SpeedBar.Position;
  PowerFlic2.CustomSpeed := SpeedBar.Position;
  SpeedLabel.Caption := IntToStr(SpeedBar.Position)+'ms ('+S+' fps)';
end;

procedure TMainForm.BrightnessBarChange(Sender: TObject);
begin
  PowerFlic1.Brightness  := BrightnessBar.Position;
  PowerFlic2.Brightness  := BrightnessBar.Position;
  BrightnessLabel.Caption := IntToStr(BrightnessBar.Position);
end;

procedure TMainForm.ContrastBarChange(Sender: TObject);
var
  S : String;
begin
  PowerFlic1.Contrast  := ContrastBar.Position / 100;
  PowerFlic2.Contrast  := ContrastBar.Position / 100;
  Str((ContrastBar.Position / 100):0:2,S);
  ContrastLabel.Caption := S;
end;

procedure TMainForm.ResetButtonClick(Sender: TObject);
begin
  SpeedBar.Position      := 70;
  BrightnessBar.Position := 0;
  ContrastBar.Position   := 100;
  SpeedBarChange(Sender);
  BrightnessBarChange(Sender);
  ContrastBarChange(Sender);
end;

procedure TMainForm.PowerFlic1FrameChange(Sender: TObject);
begin
  PowerFlic1.QueryFlicInfo(Addr(FlicInfo));
  CurFrame1.Caption   := IntToStr(FlicInfo.CurrentFrame);
  FrameShown1.Caption := IntToStr(FlicInfo.FramesPlayed);
end;

procedure TMainForm.PowerFlic2FrameChange(Sender: TObject);
begin
  PowerFlic2.QueryFlicInfo(Addr(FlicInfo));
  CurFrame2.Caption   := IntToStr(FlicInfo.CurrentFrame);
  FrameShown2.Caption := IntToStr(FlicInfo.FramesPlayed);
end;

procedure TMainForm.PowerFlic1Loop(Sender: TObject);
begin
  Inc(LoopCount1);
  FlicShown1.Caption := IntToStr(LoopCount1)+' times';
end;

procedure TMainForm.PowerFlic2Loop(Sender: TObject);
begin
  Inc(LoopCount2);
  FlicShown2.Caption := IntToStr(LoopCount2)+' times';
end;

procedure TMainForm.PowerFlic1Stop(Sender: TObject);
begin
  Status1.Caption := 'Stopped';
end;

procedure TMainForm.PowerFlic2Stop(Sender: TObject);
begin
  Status2.Caption := 'Stopped';
end;

procedure TMainForm.FormShow(Sender: TObject);
begin
  SpeedBarChange(Sender);
  BrightnessBarChange(Sender);
  ContrastBarChange(Sender);
end;

procedure TMainForm.Label12Click(Sender: TObject);
begin
  ShellExecute(MainForm.handle,
               'open',
               'http://members.xoom.com/virtuamedia/code/',
               nil,
               nil,
               0);
end;


end.
